from setuptools import setup

setup(name='hologger',
      version='0.0.7',
      packages=['hologger'],
      author='Checkill Kim',
      author_email='cortmzzang@gmail.com',
      license='MIT',
      description='Write log at db',
      )
